pub struct TimerModule { /* private fields */ }Trait Implementations
Sourceimpl Debug for TimerModule
impl Debug for TimerModule
Sourceimpl SignalingModule for TimerModule
impl SignalingModule for TimerModule
Sourcetype Incoming = TimerCommand
type Incoming = TimerCommand
The incoming websocket payload which is received as in
SignalingModule::on_websocket_messageSourcetype Outgoing = TimerEvent
type Outgoing = TimerEvent
The outgoing websocket payload that is sent to the clients
Sourcetype Internal = NoOp
type Internal = NoOp
The incoming command which is received from other
SignalingModulesSourcetype Loopback = TimerLoopback
type Loopback = TimerLoopback
Internal result type for asynchronous tasks Read more
Sourcetype JoinInfo = TimerState
type JoinInfo = TimerState
Namespaced data that can be attached to a participants
JoinSuccess messageSourcetype PeerJoinInfo = TimerPeerState
type PeerJoinInfo = TimerPeerState
Namespaced data that can be attached to the
Joined message Read moreSourcetype Error = TimerError
type Error = TimerError
The non-fatal error that can be returned from signaling module event handlers Read more
Sourcefn init(_init_data: SignalingModuleInitData) -> Option<Self>
fn init(_init_data: SignalingModuleInitData) -> Option<Self>
Creates an instance of the interface to access the module
fn on_participant_joined( &mut self, ctx: &mut ModuleContext<'_, Self>, participant_id: ParticipantId, _connection_id: ConnectionId, _is_first_connection: bool, ) -> Result<ModuleJoinData<Self>, SignalingModuleError<Self::Error>>
fn on_participant_disconnected( &mut self, ctx: &mut ModuleContext<'_, Self>, participant_id: ParticipantId, connection_id: ConnectionId, ) -> Result<(), SignalingModuleError<Self::Error>>
fn on_breakout_start( &mut self, _ctx: &mut ModuleContext<'_, Self>, rooms: &[BreakoutRoom], _duration: Option<Duration>, ) -> Result<(), SignalingModuleError<Self::Error>>
fn on_breakout_switch( &mut self, ctx: &mut ModuleContext<'_, Self>, participant_id: ParticipantId, _old_room: RoomKind, new_room: RoomKind, ) -> Result<ModuleSwitchData<Self>, SignalingModuleError<Self::Error>>
fn on_breakout_closed( &mut self, _ctx: &mut ModuleContext<'_, Self>, ) -> Result<(), SignalingModuleError<Self::Error>>
fn on_websocket_message( &mut self, ctx: &mut ModuleContext<'_, Self>, sender: ParticipantId, _connection_id: ConnectionId, payload: Self::Incoming, ) -> Result<(), SignalingModuleError<Self::Error>>
fn on_loopback_event( &mut self, ctx: &mut ModuleContext<'_, Self>, event: Self::Loopback, ) -> Result<(), SignalingModuleError<Self::Error>>
fn on_websocket_message_waiting_room( &mut self, ctx: &mut ModuleContext<'_, Self>, sender: ParticipantId, connection_id: ConnectionId, payload: Self::Incoming, ) -> Result<(), SignalingModuleError<Self::Error>>
fn on_breakout_closing( &mut self, ctx: &mut ModuleContext<'_, Self>, ) -> Result<(), SignalingModuleError<Self::Error>>
fn on_internal_command( &mut self, ctx: &mut ModuleContext<'_, Self>, command: Self::Internal, ) -> Result<(), SignalingModuleError<Self::Error>>
Sourcefn on_closing(&mut self, ctx: &mut ModuleContext<'_, Self>) -> Result<(), Error>
fn on_closing(&mut self, ctx: &mut ModuleContext<'_, Self>) -> Result<(), Error>
Destroy the module and remove all associated resources Read more